@@ -1,17 +1,19 @@
 #' MLModel Class Constructor
-#' 
+#'
 #' Create a model for use with the \pkg{MachineShop} package.
-#' 
+#'
 #' @param name character name of the object to which the model is assigned.
 #' @param label optional character descriptor for the model.
 #' @param packages character vector of packages required to use the model.
 #' @param response_types character vector of response variable types to which
-#'   the model can be fit.  Supported types are \code{"binary"},
-#'   \code{"factor"}, \code{"matrix"}, \code{"numeric"}, \code{"ordered"}, and
-#'   \code{"Surv"}.
+#'   the model can be fit.  Supported types are \code{"binary"}, =
+#'   \code{"BinomialVariate"}, \code{"DiscreteVariate"}, \code{"factor"},
+#'   \code{"matrix"}, \code{"NegBinomialVariate"}, \code{"numeric"},
+#'   \code{"ordered"}, \code{"PoissonVariate"}, and \code{"Surv"}.
 #' @param predictor_encoding character string indicating whether the model is
 #'   fit with predictor variables encoded as a \code{"\link{model.matrix}"}, a
-#'   data.frame containing the original \code{"terms"}, or unknown (default).
+#'   data.frame containing the originally specified model \code{"terms"}, or
+#'   unspecified (default).
 #' @param params list of user-specified model parameters to be passed to the
 #'   \code{fit} function.
 #' @param grid tuning grid function whose first agument \code{x} is a
@@ -29,16 +31,16 @@
 #'   \code{object} returned by \code{fit}, optional arguments passed from calls
 #'   to \code{\link{varimp}}, and an ellipsis.
 #' @param ... arguments passed from other methods.
-#' 
+#'
 #' @details
 #' If supplied, the \code{grid} function should return a list whose elements are
 #' named after and contain values of parameters to include in a tuning grid to
 #' be constructed automatically by the package.
-#' 
+#'
 #' Argument \code{data} in the \code{fit} function may be converted to a data
 #' frame with the \code{as.data.frame} function as needed.  The function should
 #' return the object resulting from the model fit.
-#' 
+#'
 #' Values returned by the \code{predict} functions should be formatted according
 #' to the response variable types below.
 #' \describe{
@@ -51,16 +53,15 @@
 #'     \code{times} if supplied or a vector of predicted survival means
 #'     otherwise.}
 #' }
-#' 
+#'
 #' The \code{varimp} function should return a vector of importance values named
 #' after the predictor variables or a matrix or data frame whose rows are named
 #' after the predictors.
-#' 
+#'
 #' @return \code{MLModel} class object.
-#' 
-#' @seealso \code{\link{models}}, \code{\link{fit}}, \code{\link{resample}},
-#' \code{\link{tune}}
-#' 
+#'
+#' @seealso \code{\link{models}}, \code{\link{fit}}, \code{\link{resample}}
+#'
 #' @examples
 #' ## Logistic regression model
 #' LogisticModel <- MLModel(
@@ -76,11 +77,11 @@
 #'     pchisq(coef(object)^2 / diag(vcov(object)), 1)
 #'   }
 #' )
-#' 
+#'
 #' library(MASS)
 #' res <- resample(type ~ ., data = Pima.tr, model = LogisticModel)
 #' summary(res)
-#' 
+#'
 MLModel <- function(name = "MLModel", label = name, packages = character(),
                     response_types = character(),
                     predictor_encoding = c(NA, "model.matrix", "terms"),
@@ -91,10 +92,9 @@ MLModel <- function(name = "MLModel", label = name, packages = character(),
                     predict = function(object, newdata, times, ...)
                       stop("no predict function"),
                     varimp = function(object, ...) NULL, ...) {
-  
-  stopifnot(response_types %in% c("binary", "factor", "matrix", "numeric",
-                                  "ordered", "Surv"))
-  
+
+  stopifnot(response_types %in% .response_types)
+
   new("MLModel",
       name = name,
       label = label,
@@ -104,34 +104,27 @@ MLModel <- function(name = "MLModel", label = name, packages = character(),
       params = params,
       grid = grid,
       fit = fit,
-      fitbits = MLFitBits(packages = packages,
-                          predict = predict,
-                          varimp = varimp))
+      predict = predict,
+      varimp = varimp)
 }
 
 
-MLFitBits <- function(...) {
-  new("MLFitBits", ...)
-}
-
-
-asMLModelFit <- function(object, Class, model, x, y) {
-  fitbits <- model@fitbits
-  fitbits@x <- x
-  fitbits@y <- y
+MLModelFit <- function(object, Class, model, x, y) {
+  model@x <- x
+  model@y <- y
 
   if (is(object, Class)) {
     object <- unMLModelFit(object)
   } else if (is(object, "MLModelFit")) {
     stop("cannot change MLModelFit class")
   }
-  
+
   if (!is(model, "MLModel")) stop("model not of class MLModel")
-  
+
   if (isS4(object)) {
-    object <- new(Class, object, fitbits = fitbits)
+    object <- new(Class, object, mlmodel = model)
   } else if (is.list(object)) {
-    object$fitbits <- fitbits
+    object$mlmodel <- model
     class(object) <- c(Class, "MLModelFit", class(object))
   } else {
     stop("unsupported object class")
@@ -142,14 +135,16 @@ asMLModelFit <- function(object, Class, model, x, y) {
 
 
 unMLModelFit <- function(object) {
-  if (!is(object, "MLModelFit")) return(object)
-  if (isS4(object)) {
-    classes <- extends(class(object))
-    as(object, classes[match("MLModelFit", classes) + 1])
-  } else {
-    object$fitbits <- NULL
-    classes <- class(object)
-    pos <- match("MLModelFit", classes)
-    structure(object, class = classes[-c(pos - 1, pos)])
-  }
+  if (is(object, "MLModelFit")) {
+    if (isS4(object)) {
+      classes <- extends(class(object))
+      pos <- match("MLModelFit", classes)
+      as(object, classes[pos + 1])
+    } else {
+      object$mlmodel <- NULL
+      classes <- class(object)
+      pos <- match("MLModelFit", classes)
+      structure(object, class = classes[-(1:pos)])
+    }
+  } else object
 }
