@@ -1,8 +1,8 @@
 #' Gradient Boosting with Regression Trees
-#' 
+#'
 #' Gradient boosting for optimizing arbitrary loss functions where regression
 #' trees are utilized as base-learners.
-#' 
+#'
 #' @param family optional \code{\link[mboost]{Family}} object.  Set
 #'   automatically according to the class type of the response variable.
 #' @param mstop number of initial boosting iterations.
@@ -25,7 +25,7 @@
 #' @param saveinfo logical indicating whether to store information about
 #'   variable selection in \code{info} slot of each \code{partynode}.
 #' @param ... additional arguments to \code{\link[partykit]{ctree_control}}.
-#' 
+#'
 #' @details
 #' \describe{
 #'   \item{Response Types:}{\code{binary}, \code{numeric}, \code{Surv}}
@@ -33,19 +33,19 @@
 #'     \code{mstop}, \code{maxdepth}
 #'   }
 #' }
-#' 
+#'
 #' Default values for the \code{NULL} arguments and further model details can be
 #' found in the source links below.
-#' 
+#'
 #' @return \code{MLModel} class object.
-#' 
+#'
 #' @seealso \code{\link[mboost]{blackboost}}, \code{\link[mboost]{Family}},
 #' \code{\link[partykit]{ctree_control}}, \code{\link{fit}},
-#' \code{\link{resample}}, \code{\link{tune}}
-#' 
+#' \code{\link{resample}}
+#'
 #' @examples
 #' library(MASS)
-#' 
+#'
 #' fit(type ~ ., data = Pima.tr, model = BlackBoostModel)
 #'
 BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
@@ -56,10 +56,10 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
                                          "Bonferroni", "MonteCarlo"),
                             mincriterion = 0, minsplit = 10, minbucket = 4,
                             maxdepth = 2, saveinfo = FALSE, ...) {
-  
+
   teststat <- match.arg(teststat)
   testtype <- match.arg(testtype)
-  
+
   args <- params(environment())
   is_main <- names(args) %in% "family"
   is_control <- names(args) %in% c("mstop", "nu", "risk", "stopintern", "trace")
@@ -73,7 +73,8 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
     name = "BlackBoostModel",
     label = "Gradient Boosting with Regression Trees",
     packages = c("mboost", "partykit"),
-    response_types = c("binary", "numeric", "Surv"),
+    response_types = c("binary", "BinomialVariate", "NegBinomialVariate",
+                       "numeric", "PoissonVariate", "Surv"),
     predictor_encoding = "terms",
     params = params,
     grid = function(x, length, ...) {
@@ -85,9 +86,12 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
     fit = function(formula, data, weights, family = NULL, ...) {
       if (is.null(family)) {
         family <- switch_class(response(data),
-                               "factor" = mboost::Binomial(),
-                               "numeric" = mboost::Gaussian(),
-                               "Surv" = mboost::CoxPH())
+                               BinomialVariate = mboost::Binomial(type = "glm"),
+                               factor = mboost::Binomial(),
+                               NegBinomialVariate = mboost::NBinomial(),
+                               numeric = mboost::Gaussian(),
+                               PoissonVariate = mboost::Poisson(),
+                               Surv = mboost::CoxPH())
       }
       mboost::blackboost(formula, data = as.data.frame(data),
                          na.action = na.pass, weights = weights,
@@ -96,10 +100,9 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
     predict = function(object, newdata, times, ...) {
       newdata <- as.data.frame(newdata)
       if (object$family@name == "Cox Partial Likelihood") {
-        y <- object$response
         lp <- drop(predict(object, type = "link"))
         new_lp <- drop(predict(object, newdata = newdata, type = "link"))
-        predict(y, lp, times, new_lp, ...)
+        predict(object$response, lp, times, new_lp, ...)
       } else {
         predict(object, newdata = newdata, type = "response")
       }
@@ -108,7 +111,7 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
       structure(mboost::varimp(object), class = "numeric")
     }
   )
-  
+
 }
 
 MLModelFunction(BlackBoostModel) <- NULL
