@@ -1,10 +1,10 @@
 #' Extreme Gradient Boosting Models
-#' 
+#'
 #' Fits models within an efficient implementation of the gradient boosting
 #' framework from Chen & Guestrin.
-#' 
+#'
 #' @rdname XGBModel
-#' 
+#'
 #' @param params list of model parameters as described in the XBoost
 #'   \href{https://xgboost.readthedocs.io/en/latest/parameter.html}{documentation}.
 #' @param nrounds maximum number of boosting iterations.
@@ -20,7 +20,7 @@
 #' @param eta,gamma,max_depth,min_child_weight,max_delta_step,subsample,colsample_bytree,colsample_bylevel,lambda,alpha,tree_method,sketch_eps,scale_pos_weight,update,refresh_leaf,process_type,grow_policy,max_leaves,max_bin,sample_type,normalize_type,rate_drop,one_drop,skip_drop,updater,feature_selector,top_k
 #'   see \code{params} reference.
 #' @param ... arguments passed to \code{XGBModel}.
-#' 
+#'
 #' @details
 #' \describe{
 #'   \item{Response Types:}{\code{factor}, \code{numeric}}
@@ -37,10 +37,10 @@
 #'   }
 #' }
 #' * included only in randomly sampled grid points
-#' 
+#'
 #' Default values for the \code{NULL} arguments and further model details can be
 #' found in the source link below.
-#' 
+#'
 #' In calls to \code{\link{varimp}} for \code{XGBTreeModel}, argument
 #' \code{metric} may be spedified as \code{"Gain"} (default) for the fractional
 #' contribution of each predictor to the total gain of its splits, as
@@ -49,41 +49,42 @@
 #' the trees.  Variable importance is automatically scaled to range from 0 to
 #' 100.  To obtain unscaled importance values, set \code{scale = FALSE}.  See
 #' example below.
-#' 
+#'
 #' @return \code{MLModel} class object.
-#' 
+#'
 #' @seealso \code{\link[xgboost:xgb.train]{xgboost}}, \code{\link{fit}},
-#' \code{\link{resample}}, \code{\link{tune}}
+#' \code{\link{resample}}
 #'
 #' @examples
 #' model_fit <- fit(Species ~ ., data = iris, model = XGBTreeModel)
 #' varimp(model_fit, metric = "Frequency", scale = FALSE)
-#' 
+#'
 XGBModel <- function(params = list(), nrounds = 1, verbose = 0,
                      print_every_n = 1) {
-  
+
   MLModel(
     name = "XGBModel",
     label = "Extreme Gradient Boosting",
     packages = "xgboost",
-    response_types = c("factor", "numeric"),
+    response_types = c("factor", "numeric", "PoissonVariate"),
     predictor_encoding = "model.matrix",
     params = params(environment()),
     fit = function(formula, data, weights, params, ...) {
       x <- model.matrix(data, intercept = FALSE)
       y <- response(data)
       response_levels <- levels(y)
-      switch_class(y,
-                   "factor" = {
-                     params$num_class <- nlevels(y)
-                     y <- as.numeric(y) - 1
-                     obj_choices <- c("multi:softprob", "binary.logistic")
-                   },
-                   "numeric" = {
-                     obj_choices <- c("reg:linear", "reg:logistic", "reg:gamma",
-                                      "reg:tweedie", "count:poisson",
-                                      "rank:pairwise", "rank:ndcg", "rank:map")
-                   })
+      obj_choices <- switch_class(y,
+                                  factor = {
+                                    params$num_class <- nlevels(y)
+                                    y <- as.numeric(y) - 1
+                                    c("multi:softprob", "binary.logistic")
+                                  },
+                                  numeric = {
+                                    c("reg:linear", "reg:logistic", "reg:gamma",
+                                      "reg:tweedie", "rank:pairwise",
+                                      "rank:ndcg", "rank:map")
+                                  },
+                                  PoissonVariate = "count:poisson")
       params$objective <- match.arg(params$objective, obj_choices)
       modelfit <- xgboost::xgboost(x, y, weight = weights, params = params, ...)
       modelfit$levels <- response_levels
@@ -114,14 +115,14 @@ XGBModel <- function(params = list(), nrounds = 1, verbose = 0,
       }
     }
   )
-  
+
 }
 
 MLModelFunction(XGBModel) <- NULL
 
 
 #' @rdname XGBModel
-#' 
+#'
 XGBDARTModel <- function(objective = NULL, base_score = 0.5,
                          eta = 0.3, gamma = 0, max_depth = 6,
                          min_child_weight = 1, max_delta_step = 0,
@@ -141,7 +142,7 @@ MLModelFunction(XGBDARTModel) <- NULL
 
 
 #' @rdname XGBModel
-#' 
+#'
 XGBLinearModel <- function(objective = NULL, base_score = 0.5,
                            lambda = 0, alpha = 0, updater = "shotgun",
                            feature_selector = "cyclic", top_k = 0, ...) {
@@ -153,7 +154,7 @@ MLModelFunction(XGBLinearModel) <- NULL
 
 
 #' @rdname XGBModel
-#' 
+#'
 XGBTreeModel <- function(objective = NULL, base_score = 0.5,
                          eta = 0.3, gamma = 0, max_depth = 6,
                          min_child_weight = 1, max_delta_step = 0,
@@ -177,7 +178,7 @@ MLModelFunction(XGBTreeModel) <- NULL
   model <- do.call(XGBModel, args, quote = TRUE)
   model@name <- name
   model@label <- label
-  
+
   params <- switch(booster,
                    "dart" = list(
                      nrounds = NULL,
@@ -204,7 +205,7 @@ MLModelFunction(XGBTreeModel) <- NULL
                      subsample = NULL,
                      colsample_bytree = NULL
                    ))
-  
+
   if (length(params)) {
     model@grid <- function(x, length, random, ...) {
       params <- params %>%
@@ -218,20 +219,21 @@ MLModelFunction(XGBTreeModel) <- NULL
         set_param("skip_drop", c(0.05, 0.95)) %>%
         set_param("lambda", c(10^-seq_inner(0, 5, length - 1), 0)) %>%
         set_param("alpha", c(10^-seq_inner(0, 5, length - 1), 0))
-      
+
       if (random) {
         params <- params %>%
           set_param("eta", seq(0.001, 0.6, length = length)) %>%
           set_param("gamma", seq(0, 10, length = length)) %>%
-          set_param("min_child_weight", 0:20) %>%
+          set_param("min_child_weight",
+                    seq(0, min(20, nrow(x)), length = length)) %>%
           set_param("colsample_bytree", seq(0.3, 0.8, length = length)) %>%
           set_param("rate_drop", seq(0.01, 0.50, length = length)) %>%
           set_param("skip_drop", seq(0.05, 0.95, length = length))
       }
-      
+
       params
     }
   }
-  
+
   model
 }
