@@ -1,10 +1,10 @@
 #' Confusion Matrix
-#' 
+#'
 #' Calculate confusion matrices of predicted and observed responses.
-#' 
+#'
 #' @name confusion
 #' @rdname confusion
-#' 
+#'
 #' @param x factor of \link[=response]{observed responses} or \link{resample}
 #'   result containing observed and predicted responses.
 #' @param y \link[=predict]{predicted responses} if not contained in \code{x}.
@@ -17,27 +17,26 @@
 #'   interpreted as expected counts.
 #' @param na.rm logical indicating whether to remove observed or predicted
 #'   responses that are \code{NA} when calculating metrics.
-#' @param ... named or unnamed \code{confusion} output to combine together with
-#'   the \code{Confusion} constructor.
-#' @param object square matrix, or object that can be converted to one, of
+#' @param ... arguments passed to other methods.
+#' @param data square matrix, or object that can be converted to one, of
 #'   cross-classified predicted and observed values in the rows and columns,
 #'   respectively.
 #' @param ordered logical indicating whether the confusion matrix row and
 #'   columns should be regarded as ordered.
-#' 
+#'
 #' @return
 #' The return value is a \code{ConfusionMatrix} class object that inherits from
 #' \code{table} if \code{x} and \code{y} responses are specified or a
-#' \code{Confusion} object that inherits from \code{list} if \code{x} is a
+#' \code{ConfusionList} object that inherits from \code{list} if \code{x} is a
 #' \code{Resamples} object.
-#'  
-#' @seealso \code{\link{plot}}, \code{\link{summary}}
-#' 
+#'
+#' @seealso \code{\link{c}}, \code{\link{plot}}, \code{\link{summary}}
+#'
 #' @examples
 #' res <- resample(Species ~ ., data = iris, model = GBMModel)
 #' (conf <- confusion(res))
 #' plot(conf)
-#' 
+#'
 confusion <- function(x, y = NULL, cutoff = MachineShop::settings("cutoff"),
                       na.rm = TRUE, ...) {
   if (na.rm) {
@@ -50,48 +49,22 @@ confusion <- function(x, y = NULL, cutoff = MachineShop::settings("cutoff"),
 
 
 #' @rdname confusion
-#' 
-Confusion <- function(...) {
-  args <- list(...)
-  
-  conf_list <- list()
-  for (i in seq(args)) {
-    x <- args[[i]]
-    if (is(x, "ConfusionMatrix")) {
-      x <- list("Model" = x)
-    } else if (!is(x, "Confusion")) {
-      stop("values to combine must be Confusion or ConfusionMatrix objects")
-    }
-    arg_name <- names(args)[i]
-    if (!is.null(arg_name) && nzchar(arg_name)) {
-      names(x) <- rep(arg_name, length(x))
-    }
-    conf_list <- c(conf_list, x)
-  }
-  names(conf_list) <- make.unique(names(conf_list))
-  
-  structure(conf_list, class = c("Confusion", "listof"))
-}
+#'
+ConfusionMatrix <- function(data = NA, ordered = FALSE) {
+  data <- as.matrix(data)
 
+  n <- nrow(data)
+  if (n != ncol(data)) stop("unequal number of rows and columns")
 
-#' @rdname confusion
-#' 
-ConfusionMatrix <- function(object = numeric(), ordered = FALSE) {
-  
-  object <- if (length(object)) as.matrix(object) else matrix(NA_real_, 0, 0)
-  
-  n <- nrow(object)
-  if (n != ncol(object)) stop("unequal number of rows and columns")
-  
-  object_dimnames <- dimnames(object)
-  if (is.null(object_dimnames)) object_dimnames <- list(NULL, NULL)
-  names(object_dimnames) <- c("Predicted", "Observed")
-  
-  object_class <- "ConfusionMatrix"
-  if (n == 2) object_class <- paste0("Binary", object_class)
-  if (ordered) object_class <- paste0("Ordered", object_class)
-  
-  new(object_class, structure(object, dimnames = object_dimnames))
+  data_dimnames <- dimnames(data)
+  if (is.null(data_dimnames)) data_dimnames <- list(NULL, NULL)
+  names(data_dimnames) <- c("Predicted", "Observed")
+
+  data_class <- "ConfusionMatrix"
+  if (n == 2) data_class <- paste0("Binary", data_class)
+  if (ordered) data_class <- paste0("Ordered", data_class)
+
+  new(data_class, structure(data, dimnames = data_dimnames))
 }
 
 
@@ -110,16 +83,16 @@ ConfusionMatrix <- function(object = numeric(), ordered = FALSE) {
   conf_list <- by(x, list(Model = x$Model), function(data) {
    confusion(data$Observed, data$Predicted, cutoff = cutoff, na.rm = FALSE)
   }, simplify = FALSE)
-  if (all(mapply(is, conf_list, "Confusion"))) {
+  if (all(mapply(is, conf_list, "ConfusionList"))) {
     conf_list <- unlist(conf_list, recursive = FALSE)
   }
-  do.call(Confusion, conf_list)
+  do.call(c, conf_list)
 }
 
 
 .confusion.Surv <- function(x, y, cutoff, ...) {
   if (is.null(cutoff)) cutoff <- 0.5
-  do.call(Confusion, .confusion_matrix(x, y, cutoff = cutoff))
+  do.call(c, .confusion_matrix(x, y, cutoff = cutoff))
 }
 
 
@@ -169,9 +142,9 @@ setMethod(".confusion_matrix", c("Surv", "SurvProbs"),
 
 setMethod(".confusion_matrix", c("Surv", "SurvEvents"),
   function(observed, predicted, ...) {
-    times <- time(predicted)
+    times <- predicted@times
     surv <- predict(survfit(observed ~ 1, se.fit = FALSE), times)
-    
+
     conf_tbl <- table(Predicted = 0:1, Observed = 0:1)
 
     structure(
