@@ -195,7 +195,7 @@ Weibull.SurvProbs <- function(x, shape = NULL, ...) {
     function(df) c(mean(df$y - shape * df$x), shape)
   }
   coef <- apply(x, 1, function(surv) {
-    df <- surv_cases(x = log(time(x)), y = log(-log(surv)),
+    df <- surv_cases(x = log(x@times), y = log(-log(surv)),
                      subset = diff(c(1, surv)) < 0)
     weibullfit(df)
   })
@@ -236,71 +236,20 @@ predict.survfit <- function(object, times, ...) {
 }
 
 
-#################### SurvMatrix Constructors and Methods ####################
-
-
-SurvMatrix <- function(object, times = NULL) {
-  object <- as.matrix(object)
-  
-  if (is.null(times)) times <- rep(NA_real_, ncol(object))
-  
-  if (length(times) != ncol(object)) {
-    stop("unequal number of survival times and predictions")
-  }
-  
-  dimnames(object) <- list(NULL, paste("Time", seq(ncol(object))))
-  
-  structure(object, class = "SurvMatrix", times = times)
-}
-
-
-#' SurvMatrix Class Constructor
-#' 
-#' Create an object of predicted survival events or probabilites for use with
-#' metrics provided by the \pkg{MachineShop} package.
-#' 
-#' @name SurvMatrix
-#' @rdname SurvMatrix
-#' 
-#' @param object matrix, or object that can be converted to one, of predicted
-#'   survival events or probabilities with columns and rows representing
-#'   prediction times and cases, respectively.
-#' @param times numeric vector of the survival prediction times.
-#' 
-#' @return Object that is of the same class as the constructor name and inherits
-#' from \code{SurvMatrix}.  Examples of these objects are the predicted survival
-#' events and probabilities returned by the \link{predict} function.
-#' 
-#' @seealso \code{\link{performance}}, \code{\link{metrics}}
-#' 
-SurvEvents <- function(object = numeric(), times = NULL) {
-  object <- SurvMatrix(object, times)
-  structure(object, class = c("SurvEvents", class(object)))
-}
-
-
-#' @rdname SurvMatrix
-#' 
-SurvProbs <- function(object = numeric(), times = NULL) {
-  object <- SurvMatrix(object, times)
-  structure(object, class = c("SurvProbs", class(object)))
-}
+#################### SurvMatrix Methods ####################
 
 
 mean.SurvProbs <- function(x, ...) {
-  apply(x, 1, function(surv) surv_mean(time(x), surv))
+  apply(x, 1, function(surv) surv_mean(x@times, surv))
 }
 
 
 predict.SurvProbs <- function(object, times, ...) {
-  idx <- findInterval(times, time(object))
+  idx <- findInterval(times, object@times)
   cbind(1, object)[, idx + 1, drop = FALSE]
 }
 
 
-time.SurvMatrix <- function(x, ...) attr(x, "times")
-
-
 #################### Survival Utility Functions ####################
 
 
