@@ -10,15 +10,15 @@ VarImp.default <- function(object, scale = TRUE, ...) {
   idx <- idx * (rownames(object)[idx] != "(Intercept)")
   object <- object[idx, , drop = FALSE]
   if (scale) {
-    scale_center <- min(object)
-    scale_scale <- diff(range(object)) / 100
-    object <- (object - scale_center) / scale_scale
+    object_shift <- min(object)
+    object_scale <- diff(range(object)) / 100
+    object <- (object - object_shift) / object_scale
   } else {
-    scale_center = 0
-    scale_scale = 1
+    object_shift = 0
+    object_scale = 1
   }
-  
-  new("VarImp", object, center = scale_center, scale = scale_scale)
+
+  new("VarImp", object, shift = object_shift, scale = object_scale)
 }
 
 
@@ -33,23 +33,23 @@ VarImp.numeric <- function(object, ...) {
 
 
 #' Variable Importance
-#' 
+#'
 #' Calculate measures of the relative importance of predictors in a model.
-#' 
+#'
 #' @param object model \link{fit} result.
 #' @param scale logical indicating whether importance measures should be scaled
 #'   to range from 0 to 100.
 #' @param ... arguments passed to model-specific variable importance functions.
-#' 
+#'
 #' @return \code{VarImp} class object.
-#' 
+#'
 #' @seealso \code{\link{plot}}
 #'
 #' @examples
 #' ## Survival response example
 #' library(survival)
 #' library(MASS)
-#' 
+#'
 #' gbm_fit <- fit(Surv(time, status != 2) ~ sex + age + year + thickness + ulcer,
 #'                data = Melanoma, model = GBMModel)
 #' (vi <- varimp(gbm_fit))
@@ -57,30 +57,48 @@ VarImp.numeric <- function(object, ...) {
 #'
 varimp <- function(object, scale = TRUE, ...) {
   stopifnot(is(object, "MLModelFit"))
-  requireModelNamespaces(fitbit(object, "packages"))
-  vi <- fitbit(object, "varimp")(unMLModelFit(object), ...)
+  model <- as.MLModel(object)
+  requireModelNamespaces(model@packages)
+  vi <- model@varimp(unMLModelFit(object), ...)
   if (is.null(vi)) vi <- varimp_undef(object)
   VarImp(vi, scale = scale)
 }
 
 
-varimp_wald <- function(object, ...) {
-  UseMethod("varimp_wald")
+varimp_pval <- function(object, ...) {
+  UseMethod("varimp_pval")
 }
 
 
-varimp_wald.default <- function(object, ...) {
-  varimp_wald(coef(object), diag(vcov(object)))
+varimp_pval.default <- function(object, ...) {
+  varimp_pval(coef(object), diag(vcov(object)), ...)
 }
 
 
-varimp_wald.numeric <- function(object, var, ...) {
-  pchisq(object^2 / var, 1)
+varimp_pval.glm <- function(object, base = exp(1), ...) {
+  anova <- drop1(object, test = "Chisq")
+  -log(anova[-1, "Pr(>Chi)", drop = FALSE], base = base)
+}
+
+
+varimp_pval.lm <- function(object, base = exp(1), ...) {
+  anova <- drop1(object, test = "F")
+  -log(anova[-1, "Pr(>F)", drop = FALSE], base = base)
+}
+
+
+varimp_pval.mlm <- function(object, ...) {
+  varimp_pval.default(object, ...)
+}
+
+
+varimp_pval.numeric <- function(object, var, base = exp(1), ...) {
+  -log(pchisq(object^2 / var, 1, lower.tail = FALSE), base = base)
 }
 
 
 varimp_undef <- function(object) {
   warn("variable importance not defined for ", class(object)[1])
-  varnames <- labels(terms(fitbit(object, "x")))
+  varnames <- labels(terms(as.MLModel(object)@x))
   structure(rep(NA_real_, length(varnames)), names = varnames)
 }
